@@ -37,13 +37,15 @@ import json
 from processor.logging.log_handler import getlogger
 from processor.helper.json.json_utils import get_field_value, json_from_file,\
     get_container_snapshot_json_files, SNAPSHOT, JSONTEST,\
-    collectiontypes, get_json_files, TEST, MASTERTEST, save_json_to_file
-from processor.helper.config.config_utils import config_value, framework_dir
+    collectiontypes, get_json_files, TEST, MASTERTEST, save_json_to_file, get_field_value_with_default
+from processor.helper.config.config_utils import config_value, framework_dir, SINGLETEST
 from processor.database.database import DATABASE, DBNAME, get_documents, sort_field, update_one_document
 from processor.connector.snapshot_azure import populate_azure_snapshot
 from processor.connector.snapshot_custom import populate_custom_snapshot, get_custom_data
 from processor.connector.snapshot_aws import populate_aws_snapshot
 from processor.connector.snapshot_google import populate_google_snapshot
+from processor.helper.config.rundata_utils import get_from_currentdata
+
 
 
 logger = getlogger()
@@ -197,6 +199,7 @@ def container_snapshots_filesystem(container):
     reporting_path = config_value('REPORTING', 'reportOutputFolder')
     json_dir = '%s/%s/%s' % (framework_dir(), reporting_path, container)
     logger.info(json_dir)
+    singletest = get_from_currentdata(SINGLETEST)
     test_files = get_json_files(json_dir, JSONTEST)
     logger.info('\n'.join(test_files))
     for test_file in test_files:
@@ -205,7 +208,16 @@ def container_snapshots_filesystem(container):
             snapshot = test_json_data['snapshot'] if 'snapshot' in test_json_data else ''
             if snapshot:
                 file_name = snapshot if snapshot.endswith('.json') else '%s.json' % snapshot
-                snapshots.append(file_name)
+                if singletest:
+                    testsets = get_field_value_with_default(test_json_data, 'testSet', [])
+                    for testset in testsets:
+                        for testcase in testset['cases']:
+                            if ('testId' in testcase and testcase['testId'] == singletest) or \
+                                    ('masterTestId' in testcase and testcase['masterTestId'] == singletest):
+                                if file_name not in snapshots:
+                                    snapshots.append(file_name)
+                else:
+                    snapshots.append(file_name)
 
     test_files = get_json_files(json_dir, MASTERTEST)
     logger.info('\n'.join(test_files))
@@ -216,7 +228,17 @@ def container_snapshots_filesystem(container):
             if snapshot:
                 file_name = snapshot if snapshot.endswith('.json') else '%s.json' % snapshot
                 parts = file_name.split('.')
-                snapshots.append('%s_gen.%s' % (parts[0], parts[-1]))
+                file_name = '%s_gen.%s' % (parts[0], parts[-1])
+                if singletest:
+                    testsets = get_field_value_with_default(test_json_data, 'testSet', [])
+                    for testset in testsets:
+                        for testcase in testset['cases']:
+                            if ('testId' in testcase and testcase['testId'] == singletest) or \
+                                    ('masterTestId' in testcase and testcase['masterTestId'] == singletest):
+                                if file_name not in snapshots:
+                                    snapshots.append(file_name)
+                else:
+                    snapshots.append(file_name)
     return list(set(snapshots))
 
 
